import { Provide, Inject } from '@midwayjs/decorator';
import { Config, InjectClient } from '@midwayjs/core';
import { FrameworkErrorEnum, ServiceError } from 'free-midway-component';
import * as fs from 'node:fs';
import * as Path from 'node:path';
import { HttpServiceFactory, HttpService } from '@midwayjs/axios';
const moment = require('moment');
const sharp = require('sharp');
const sep = Path.sep;
@Provide()
export class FileService {
  @Config('export.root_path')
  root_path;

  @Config('export.file_type')
  file_type;

  @InjectClient(HttpServiceFactory, 'Axios')
  Axios: HttpService;

  @Inject()
  ctx;

  async upload(files, fields) {
    const path = `${this.root_path}${sep}${this.file_type}`;
    if (!path) {
      throw new ServiceError(
        '服务端没有设置存储路径',
        FrameworkErrorEnum.SERVICE_FAULT
      );
    }
    if (!fs.existsSync(path)) {
      // 如果不存在文件夹,就创建
      this.mkdir(path);
    }
    // TODO: 指定文件名或者按时间生成文件名
    // const name = moment().format('YYYYMMDDHHmmss');
    const filePath = `${path}${sep}`;
    for (const val of files) {
      const filename = moment().format('YYYYMMDDHHmmss');
      await sharp(val.data)
        .toFormat('jpg', { mozjpeg: true })
        .toFile(`${filePath}${filename}.jpg`);
      return {
        id: filename,
        name: `${filename}.jpg`,
        uri: `/files/friendSchool/${filename}.jpg`,
      };
    }
  }
  // 创建文件夹
  mkdir(dirname) {
    if (fs.existsSync(dirname)) {
      return true;
    }
    if (this.mkdir(Path.dirname(dirname))) {
      fs.mkdirSync(dirname);
      return true;
    }
  }
}
